#!/usr/bin/python
#
# File:		mk_zicog_image.py
#
# Author:	Michael Rychlik
#
# Version:	0.1
#
# Convert a collection of SIMH AltairZ80 disk image files into an SD card image
# suitable for use with the ZiCog Z80 emulator.
#
# SORRY to anyone reading this, this is a quick hack, no error checking etc etc.

# List all files to be included in this image here. First 8 must be Altair floppy images, then Altair 8M hard disk images
input_files = ['cpm2.dsk', 'cpm3.dsk', 'bdsc160.dsk', 'wordstar.dsk', 'vedit.dsk', 'basic.dsk', 'hitechc.dsk', 'pascal.dsk', 'i.dsk']

output_file_name = 'zicog.img'


# Size of a block on micro SD FLASH card
sd_block_size = 512

# Open the output image file
zicog_dsk = open(output_file_name, 'wb')

file_no = 0
for in_file in input_files:
	print "Processing:", in_file

	# Open an input file
	simh_dsk = open(in_file, 'rb')

	# Check if floppy or hard drive
	if file_no < 8:
		# First 8 disks are treated as Altair floppies
		print "    Floppy"
		tracks = 254
		sectors_per_track = 32
		sector_size = 137 
	else:
		# Drives 8 and up are treated as Altair hard disks
		print "    Hard Disk"
		tracks = 2048
		sectors_per_track = 32
		sector_size = 128 
	padding = '\0' * (sd_block_size - sector_size)

	count = 0
	while (count < (tracks * sectors_per_track)):
		# Read a sector of the input file
		sector = simh_dsk.read(sector_size);

		# Create a block from a sector padded with zeros
		block = sector + padding

		# Write a sd block to the output file
		zicog_dsk.write(block)

		count = count + 1

	# Count this file
	file_no = file_no + 1

	# Close this input file
	simh_dsk.close

# Close the output file.
zicog_dsk.close

